@@ -1,7 +1,7 @@
 // qjackctlMainForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2008, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -384,6 +384,7 @@ bool qjackctlMainForm::setup ( qjackctlSetup *pSetup )
 	m_pConnectionsForm = new qjackctlConnectionsForm (pParent, wflags);
 	m_pPatchbayForm    = new qjackctlPatchbayForm    (pParent, wflags);
 	// Setup appropriately...
+	m_pMessagesForm->setLogging(m_pSetup->bMessagesLog, m_pSetup->sMessagesLogPath);
 	m_pConnectionsForm->setup(m_pSetup);
 	m_pPatchbayForm->setup(m_pSetup);
 
@@ -788,12 +789,14 @@ void qjackctlMainForm::startJack (void)
 
 	// Build process arguments...
 	bool bDummy     = (m_preset.sDriver == "dummy");
+	bool bSun       = (m_preset.sDriver == "sun");
 	bool bOss       = (m_preset.sDriver == "oss");
 	bool bAlsa      = (m_preset.sDriver == "alsa");
 	bool bPortaudio = (m_preset.sDriver == "portaudio");
 	bool bCoreaudio = (m_preset.sDriver == "coreaudio");
 	bool bFreebob   = (m_preset.sDriver == "freebob");
 	bool bFirewire  = (m_preset.sDriver == "firewire");
+	bool bNet       = (m_preset.sDriver == "net");
 	if (m_preset.bVerbose)
 		args.append("-v");
 	if (m_preset.bRealtime) {
@@ -825,7 +828,7 @@ void qjackctlMainForm::startJack (void)
 		args.append("-r" + QString::number(m_preset.iSampleRate));
 	if (m_preset.iFrames > 0)
 		args.append("-p" + QString::number(m_preset.iFrames));
-	if (bAlsa || bOss || bFreebob || bFirewire) {
+	if (bAlsa || bSun || bOss || bFreebob || bFirewire) {
 		if (m_preset.iPeriods > 0)
 			args.append("-n" + QString::number(m_preset.iPeriods));
 	}
@@ -861,7 +864,7 @@ void qjackctlMainForm::startJack (void)
 			args.append("-X" + m_preset.sMidiDriver);
 #endif
 	}
-	else if (bOss) {
+	else if (bOss || bSun) {
 		if (m_preset.bIgnoreHW)
 			args.append("-b");
 		if (m_preset.iWordLength > 0)
@@ -879,7 +882,7 @@ void qjackctlMainForm::startJack (void)
 		else if (m_preset.iOutChannels > 0)
 			args.append("-o" + QString::number(m_preset.iOutChannels));
 	}
-	else if (bCoreaudio || bPortaudio || bFirewire) {
+	else if (bCoreaudio || bPortaudio || bFirewire || bNet) {
 		if (m_preset.iInChannels > 0  && m_preset.iAudio != QJACKCTL_PLAYBACK)
 			args.append("-i" + QString::number(m_preset.iInChannels));
 		if (m_preset.iOutChannels > 0 && m_preset.iAudio != QJACKCTL_CAPTURE)
@@ -924,7 +927,7 @@ void qjackctlMainForm::startJack (void)
 		if (m_preset.bHWMeter)
 			args.append("-M");
 	}
-	if (bAlsa || bOss || bCoreaudio || bPortaudio || bFreebob) {
+	if (bAlsa || bSun || bOss || bCoreaudio || bPortaudio || bFreebob) {
 		if (m_preset.iInLatency > 0)
 			args.append("-I" + QString::number(m_preset.iInLatency));
 		if (m_preset.iOutLatency > 0)
@@ -1866,8 +1869,8 @@ void qjackctlMainForm::timerSlot (void)
 			m_iJackDirty = 0;
 			if (m_pSetup->bActivePatchbay) {
 				appendMessagesColor(
-					tr("Audio active patchbay scan") + sEllipsis, "#6699cc");
-				m_pPatchbayRack->connectAudioScan(m_pJackClient);
+					tr("JACK active patchbay scan") + sEllipsis, "#6699cc");
+				m_pPatchbayRack->connectJackScan(m_pJackClient);
 			}
 			refreshJackConnections();
 		}
@@ -1876,8 +1879,8 @@ void qjackctlMainForm::timerSlot (void)
 			m_iAlsaDirty = 0;
 			if (m_pSetup->bActivePatchbay) {
 				appendMessagesColor(
-					tr("MIDI active patchbay scan") + sEllipsis, "#99cc66");
-				m_pPatchbayRack->connectMidiScan(m_pAlsaSeq);
+					tr("ALSA active patchbay scan") + sEllipsis, "#99cc66");
+				m_pPatchbayRack->connectAlsaScan(m_pAlsaSeq);
 			}
 			refreshAlsaConnections();
 		}
@@ -2342,6 +2345,8 @@ void qjackctlMainForm::showSetupForm (void)
 		if (m_pSetup->sConnectionsFont.isEmpty() && m_pConnectionsForm)
 			m_pSetup->sConnectionsFont = m_pConnectionsForm->connectionsFont().toString();
 		// To track down deferred or immediate changes.
+		bool    bOldMessagesLog         = m_pSetup->bMessagesLog; 
+		QString sOldMessagesLogPath     = m_pSetup->sMessagesLogPath;
 		QString sOldMessagesFont        = m_pSetup->sMessagesFont;
 		QString sOldDisplayFont1        = m_pSetup->sDisplayFont1;
 		QString sOldDisplayFont2        = m_pSetup->sDisplayFont2;
@@ -2371,6 +2376,11 @@ void qjackctlMainForm::showSetupForm (void)
 		// Show the setup dialog...
 		if (pSetupForm->exec()) {
 			// Check wheather something immediate has changed.
+			if (( bOldMessagesLog && !m_pSetup->bMessagesLog) ||
+				(!bOldMessagesLog &&  m_pSetup->bMessagesLog) ||
+				(sOldMessagesLogPath != m_pSetup->sMessagesLogPath))
+				m_pMessagesForm->setLogging(
+					m_pSetup->bMessagesLog, m_pSetup->sMessagesLogPath);
 			if (( bOldBezierLines && !m_pSetup->bBezierLines) ||
 				(!bOldBezierLines &&  m_pSetup->bBezierLines))
 				updateBezierLines();
