@@ -1,7 +1,7 @@
 // qjackctlSetup.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2008, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -68,6 +68,8 @@ qjackctlSetup::qjackctlSetup (void)
 	bAutoRefresh             = m_settings.value("/AutoRefresh", false).toBool();
 	iTimeRefresh             = m_settings.value("/TimeRefresh", 10).toInt();
 #endif
+	bMessagesLog             = m_settings.value("/MessagesLog", false).toBool();
+	sMessagesLogPath         = m_settings.value("/MessagesLogPath", "qjackctl.log").toString();
 	bBezierLines             = m_settings.value("/BezierLines", false).toBool();
 	iTimeDisplay             = m_settings.value("/TimeDisplay", 0).toInt();
 	iTimeFormat              = m_settings.value("/TimeFormat", 0).toInt();
@@ -156,6 +158,8 @@ qjackctlSetup::~qjackctlSetup (void)
 	m_settings.setValue("/AutoRefresh",             bAutoRefresh);
 	m_settings.setValue("/TimeRefresh",             iTimeRefresh);
 #endif
+	m_settings.setValue("/MessagesLog",             bMessagesLog);
+	m_settings.setValue("/MessagesLogPath",         sMessagesLogPath);
 	m_settings.setValue("/BezierLines",             bBezierLines);
 	m_settings.setValue("/TimeDisplay",             iTimeDisplay);
 	m_settings.setValue("/TimeFormat",              iTimeFormat);
@@ -409,7 +413,7 @@ void qjackctlSetup::print_usage ( const char *arg0 )
 	out << "  -s, --start" + sEot +
 		QObject::tr("Start JACK audio server immediately") + sEol;
 	out << "  -p, --preset=[label]" + sEot +
-		QObject::tr("Set default setings preset name") + sEol;
+		QObject::tr("Set default settings preset name") + sEol;
 	out << "  -h, --help" + sEot +
 		QObject::tr("Show help about command line options") + sEol;
 	out << "  -v, --version" + sEot +
@@ -463,8 +467,8 @@ bool qjackctlSetup::parse_args ( int argc, char **argv )
 			out << QObject::tr("Qt: %1\n").arg(qVersion());
 			out << QObject::tr(QJACKCTL_TITLE ": %1\n").arg(QJACKCTL_VERSION);
 			return false;
-		}
-		else {
+		}	// FIXME: Avoid auto-start jackd stuffed args!
+		else if (sArg != "-T" && sArg != "-ndefault") {
 			// Here starts the optional command line...
 			sCmdLine += sArg;
 			iCmdArgs++;
