@@ -1,7 +1,7 @@
 // qjackctlSetup.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2008, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -127,6 +127,8 @@ public:
 	bool    bAutoRefresh;
 	int     iTimeRefresh;
 #endif
+	bool    bMessagesLog;
+	QString sMessagesLogPath;
 	bool    bBezierLines;
 	int     iTimeDisplay;
 	int     iTimeFormat;
