@@ -1,7 +1,7 @@
 // qjackctlSetupForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2008, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -297,6 +297,15 @@ qjackctlSetupForm::qjackctlSetupForm (
 		SIGNAL(editTextChanged(const QString&)),
 		SLOT(optionsChanged()));
 #endif
+	QObject::connect(m_ui.MessagesLogCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(optionsChanged()));
+	QObject::connect(m_ui.MessagesLogPathComboBox,
+		SIGNAL(editTextChanged(const QString&)),
+		SLOT(optionsChanged()));
+	QObject::connect(m_ui.MessagesLogPathToolButton,
+		SIGNAL(clicked()),
+		SLOT(browseMessagesLogPath()));
 	QObject::connect(m_ui.TransportTimeRadioButton,
 		SIGNAL(toggled(bool)),
 		SLOT(optionsChanged()));
@@ -452,6 +461,7 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	m_pSetup->loadComboBoxHistory(m_ui.PostShutdownScriptShellComboBox);
 	m_pSetup->loadComboBoxHistory(m_ui.XrunRegexComboBox);
 	m_pSetup->loadComboBoxHistory(m_ui.ActivePatchbayPathComboBox);
+	m_pSetup->loadComboBoxHistory(m_ui.MessagesLogPathComboBox);
 	m_pSetup->loadComboBoxHistory(m_ui.ServerConfigNameComboBox);
 
 	// Load Options...
@@ -482,6 +492,9 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	m_ui.AutoRefreshCheckBox->setVisible(false);
 	m_ui.TimeRefreshComboBox->setVisible(false);
 #endif
+	m_ui.MessagesLogCheckBox->setChecked(m_pSetup->bMessagesLog);
+	setComboBoxCurrentText(m_ui.MessagesLogPathComboBox,
+		m_pSetup->sMessagesLogPath);
 	m_ui.BezierLinesCheckBox->setChecked(m_pSetup->bBezierLines);
 
 	// Load some other defaults...
@@ -829,41 +842,41 @@ void qjackctlSetupForm::computeLatency (void)
 		m_ui.LatencyTextValue->setText(QString::number(lat, 'g', 3) + " " + tr("msec"));
 	else
 		m_ui.LatencyTextValue->setText(tr("n/a"));
-
-	m_ui.OkPushButton->setEnabled(m_iDirtySettings > 0 || m_iDirtyOptions > 0);
 }
 
 
 void qjackctlSetupForm::changeDriverAudio ( const QString& sDriver, int iAudio )
 {
+	bool bSun        = (sDriver == "sun");
 	bool bOss        = (sDriver == "oss");
 	bool bAlsa       = (sDriver == "alsa");
 	bool bCoreaudio  = (sDriver == "coreaudio");
 	bool bPortaudio  = (sDriver == "portaudio");
 	bool bFreebob    = (sDriver == "freebob");
 	bool bFirewire   = (sDriver == "firewire");
+	bool bNet        = (sDriver == "net");
 	bool bInEnabled  = false;
 	bool bOutEnabled = false;
 
 	switch (iAudio) {
 	case QJACKCTL_DUPLEX:
-		bInEnabled  = (bOss || bAlsa || bCoreaudio || bPortaudio);
-		bOutEnabled = (bOss || bAlsa || bCoreaudio || bPortaudio);
+		bInEnabled  = (bSun || bOss || bAlsa || bCoreaudio || bPortaudio || bNet);
+		bOutEnabled = (bSun || bOss || bAlsa || bCoreaudio || bPortaudio || bNet);
 		break;
 	case QJACKCTL_CAPTURE:
-		bInEnabled  = (bOss || bCoreaudio || bPortaudio);
+		bInEnabled  = (bSun || bOss || bCoreaudio || bPortaudio || bNet);
 		break;
 	case QJACKCTL_PLAYBACK:
-		bOutEnabled = (bOss || bCoreaudio || bPortaudio);
+		bOutEnabled = (bSun || bOss || bCoreaudio || bPortaudio || bNet);
 		break;
 	}
 
-	m_ui.InDeviceTextLabel->setEnabled(bInEnabled && (bAlsa || bOss));
-	m_ui.InDeviceComboBox->setEnabled(bInEnabled && (bAlsa || bOss));
-	m_ui.InDeviceToolButton->setEnabled(bInEnabled && (bAlsa || bOss));
-	m_ui.OutDeviceTextLabel->setEnabled(bOutEnabled && (bAlsa || bOss));
-	m_ui.OutDeviceComboBox->setEnabled(bOutEnabled && (bAlsa || bOss));
-	m_ui.OutDeviceToolButton->setEnabled(bOutEnabled && (bAlsa || bOss));
+	m_ui.InDeviceTextLabel->setEnabled(bInEnabled && (bAlsa || bSun || bOss));
+	m_ui.InDeviceComboBox->setEnabled(bInEnabled && (bAlsa || bSun || bOss));
+	m_ui.InDeviceToolButton->setEnabled(bInEnabled && (bAlsa || bSun || bOss));
+	m_ui.OutDeviceTextLabel->setEnabled(bOutEnabled && (bAlsa || bSun || bOss));
+	m_ui.OutDeviceComboBox->setEnabled(bOutEnabled && (bAlsa || bSun || bOss));
+	m_ui.OutDeviceToolButton->setEnabled(bOutEnabled && (bAlsa || bSun || bOss));
 
 	m_ui.InChannelsTextLabel->setEnabled(bInEnabled
 		|| ((bAlsa || bFirewire) && iAudio != QJACKCTL_PLAYBACK));
@@ -874,13 +887,13 @@ void qjackctlSetupForm::changeDriverAudio ( const QString& sDriver, int iAudio )
 	m_ui.OutChannelsSpinBox->setEnabled(bOutEnabled
 		|| ((bAlsa || bFirewire) && iAudio != QJACKCTL_CAPTURE));
 
-	m_ui.InLatencyTextLabel->setEnabled(bInEnabled
+	m_ui.InLatencyTextLabel->setEnabled(bInEnabled && !bNet
 		|| ((bAlsa || bFreebob) && iAudio != QJACKCTL_PLAYBACK));
-	m_ui.InLatencySpinBox->setEnabled(bInEnabled
+	m_ui.InLatencySpinBox->setEnabled(bInEnabled && !bNet
 		|| ((bAlsa || bFreebob) && iAudio != QJACKCTL_PLAYBACK));
-	m_ui.OutLatencyTextLabel->setEnabled(bOutEnabled
+	m_ui.OutLatencyTextLabel->setEnabled(bOutEnabled && !bNet
 		|| ((bAlsa || bFreebob) && iAudio != QJACKCTL_CAPTURE));
-	m_ui.OutLatencySpinBox->setEnabled(bOutEnabled
+	m_ui.OutLatencySpinBox->setEnabled(bOutEnabled && !bNet
 		|| ((bAlsa || bFreebob) && iAudio != QJACKCTL_CAPTURE));
 
 	computeLatency();
@@ -902,12 +915,14 @@ void qjackctlSetupForm::changeDriver ( const QString& sDriver )
 void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdate )
 {
 	bool bDummy     = (sDriver == "dummy");
+	bool bSun       = (sDriver == "sun");
 	bool bOss       = (sDriver == "oss");
 	bool bAlsa      = (sDriver == "alsa");
 	bool bPortaudio = (sDriver == "portaudio");
 	bool bCoreaudio = (sDriver == "coreaudio");
 	bool bFreebob   = (sDriver == "freebob");
 	bool bFirewire  = (sDriver == "firewire");
+//	bool bNet       = (sDriver == "net");
 
 	m_ui.NoMemLockCheckBox->setEnabled(!bCoreaudio);
 	m_ui.UnlockMemCheckBox->setEnabled(!bCoreaudio
@@ -919,7 +934,7 @@ void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdat
 	m_ui.HWMonCheckBox->setEnabled(bAlsa);
 	m_ui.HWMeterCheckBox->setEnabled(bAlsa);
 
-	m_ui.IgnoreHWCheckBox->setEnabled(bOss);
+	m_ui.IgnoreHWCheckBox->setEnabled(bSun || bOss);
 
 #ifdef CONFIG_COREAUDIO
 	m_ui.PriorityTextLabel->setEnabled(false);
@@ -930,14 +945,14 @@ void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdat
 	m_ui.PrioritySpinBox->setEnabled(bPriorityEnabled);
 #endif
 
-	m_ui.PeriodsTextLabel->setEnabled(bAlsa || bOss || bFreebob || bFirewire);
-	m_ui.PeriodsSpinBox->setEnabled(bAlsa || bOss || bFreebob || bFirewire);
+	m_ui.PeriodsTextLabel->setEnabled(bAlsa || bSun || bOss || bFreebob || bFirewire);
+	m_ui.PeriodsSpinBox->setEnabled(bAlsa || bSun || bOss || bFreebob || bFirewire);
 
 	if (bUpdate && (bFreebob || bFirewire) && m_ui.PeriodsSpinBox->value() < 3)
 		m_ui.PeriodsSpinBox->setValue(3);
 
-	m_ui.WordLengthTextLabel->setEnabled(bOss);
-	m_ui.WordLengthComboBox->setEnabled(bOss);
+	m_ui.WordLengthTextLabel->setEnabled(bSun || bOss);
+	m_ui.WordLengthComboBox->setEnabled(bSun || bOss);
 
 	m_ui.WaitTextLabel->setEnabled(bDummy);
 	m_ui.WaitComboBox->setEnabled(bDummy);
@@ -972,6 +987,8 @@ void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdat
 // Stabilize current form state.
 void qjackctlSetupForm::stabilizeForm (void)
 {
+	bool bValid = (m_iDirtySettings > 0 || m_iDirtyOptions > 0);
+
 	QString sPreset = m_ui.PresetComboBox->currentText();
 	if (!sPreset.isEmpty()) {
 		bool bPreset = (m_pSetup->presets.contains(sPreset));
@@ -1011,10 +1028,24 @@ void qjackctlSetupForm::stabilizeForm (void)
 	bEnabled = m_ui.ActivePatchbayCheckBox->isChecked();
 	m_ui.ActivePatchbayPathComboBox->setEnabled(bEnabled);
 	m_ui.ActivePatchbayPathToolButton->setEnabled(bEnabled);
+	if (bEnabled && bValid) {
+		const QString& sPath = m_ui.ActivePatchbayPathComboBox->currentText();
+		bValid = (!sPath.isEmpty() && QFileInfo(sPath).exists());
+	}
+
 #ifdef CONFIG_AUTO_REFRESH
 	m_ui.TimeRefreshComboBox->setEnabled(
 		m_ui.AutoRefreshCheckBox->isChecked());
 #endif
+
+	bEnabled = m_ui.MessagesLogCheckBox->isChecked();
+	m_ui.MessagesLogPathComboBox->setEnabled(bEnabled);
+	m_ui.MessagesLogPathToolButton->setEnabled(bEnabled);
+	if (bEnabled && bValid) {
+		const QString& sPath = m_ui.MessagesLogPathComboBox->currentText();
+		bValid = !sPath.isEmpty();
+	}
+
 	m_ui.MessagesLimitLinesComboBox->setEnabled(
 		m_ui.MessagesLimitCheckBox->isChecked());
 
@@ -1028,10 +1059,15 @@ void qjackctlSetupForm::stabilizeForm (void)
 	m_ui.AliasesEditingCheckBox->setEnabled(
 		m_ui.AliasesEnabledCheckBox->isChecked());
 
+	m_ui.DelayedSetupCheckBox->setEnabled(
+		!m_ui.StartMinimizedCheckBox->isChecked());
+
 	m_ui.TransportButtonsCheckBox->setEnabled(
 		m_ui.LeftButtonsCheckBox->isChecked());
 
 	changeDriverUpdate(m_ui.DriverComboBox->currentText(), false);
+
+	m_ui.OkPushButton->setEnabled(bValid);
 }
 
 
@@ -1107,10 +1143,11 @@ static OSStatus getDeviceUIDFromID( AudioDeviceID id,
 void qjackctlSetupForm::deviceMenu( QLineEdit *pLineEdit,
 	QToolButton *pToolButton, int iAudio )
 {
-	// FIXME: Only valid for ALSA and OSS devices,
+	// FIXME: Only valid for ALSA, Sun and OSS devices,
 	// for the time being... and also CoreAudio ones too.
 	const QString& sDriver = m_ui.DriverComboBox->currentText();
 	bool bAlsa      = (sDriver == "alsa");
+	bool bSun       = (sDriver == "sun");
 	bool bOss       = (sDriver == "oss");
 #ifdef CONFIG_COREAUDIO
 	bool bCoreaudio = (sDriver == "coreaudio");
@@ -1170,6 +1207,27 @@ void qjackctlSetupForm::deviceMenu( QLineEdit *pLineEdit,
 #endif 	// CONFIG_ALSA_SEQ
 	}	// Enumerate the OSS Audio devices...
 	else
+	if (bSun) {
+		QFile file("/var/run/dmesg.boot");
+		if (file.open(QIODevice::ReadOnly)) {
+			QTextStream stream(&file);
+			QString sLine;
+			QRegExp rxDevice("audio([0-9]) at (.*)");
+			while (!stream.atEnd()) {
+				sLine = stream.readLine();
+				if (rxDevice.exactMatch(sLine)) {
+					sName = "/dev/audio" + rxDevice.cap(1);
+					sText = sName + '\t' + rxDevice.cap(2);
+					pAction = menu.addAction(sText);
+					pAction->setCheckable(true);
+					pAction->setChecked(sCurName == sName);
+					++iCards;
+				}
+			}
+			file.close();
+		}
+	}
+	else
 	if (bOss) {
 		QFile file("/dev/sndstat");
 		if (file.open(QIODevice::ReadOnly)) {
@@ -1468,6 +1526,24 @@ void qjackctlSetupForm::browseActivePatchbayPath()
 }
 
 
+// Messages log path browse slot.
+void qjackctlSetupForm::browseMessagesLogPath()
+{
+	QString sFileName = QFileDialog::getSaveFileName(
+		this,											// Parent.
+		tr("Messages Log"),				                // Caption.
+		m_ui.MessagesLogPathComboBox->currentText(),	// Start here.
+		tr("Log files") + " (*.log)"	                // Filter (log files)
+	);
+
+	if (!sFileName.isEmpty()) {
+		setComboBoxCurrentText(m_ui.MessagesLogPathComboBox, sFileName);
+		m_ui.MessagesLogPathComboBox->setFocus();
+		optionsChanged();
+	}
+}
+
+
 // The display font 1 (big time) selection dialog.
 void qjackctlSetupForm::chooseDisplayFont1()
 {
@@ -1592,6 +1668,8 @@ void qjackctlSetupForm::accept (void)
 		m_pSetup->bAutoRefresh             = m_ui.AutoRefreshCheckBox->isChecked();
 		m_pSetup->iTimeRefresh             = m_ui.TimeRefreshComboBox->currentText().toInt();
 #endif
+		m_pSetup->bMessagesLog             = m_ui.MessagesLogCheckBox->isChecked();
+		m_pSetup->sMessagesLogPath         = m_ui.MessagesLogPathComboBox->currentText();
 		m_pSetup->bBezierLines             = m_ui.BezierLinesCheckBox->isChecked();
 		// Save Defaults...
 		m_pSetup->iTimeDisplay             = m_pTimeDisplayButtonGroup->checkedId();
@@ -1635,6 +1713,7 @@ void qjackctlSetupForm::accept (void)
 	m_pSetup->saveComboBoxHistory(m_ui.PostShutdownScriptShellComboBox);
 	m_pSetup->saveComboBoxHistory(m_ui.XrunRegexComboBox);
 	m_pSetup->saveComboBoxHistory(m_ui.ActivePatchbayPathComboBox);
+	m_pSetup->saveComboBoxHistory(m_ui.MessagesLogPathComboBox);
 	m_pSetup->saveComboBoxHistory(m_ui.ServerConfigNameComboBox);
 
 	// Just go with dialog acceptance.
