@@ -1,7 +1,7 @@
 // qjackctlSocketForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2008, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -96,6 +96,12 @@ protected slots:
 
 protected:
 
+	void updateJackClients(int iSocketType);
+	void updateAlsaClients(int iSocketType);
+
+	void updateJackPlugs(int iSocketType);
+	void updateAlsaPlugs(int iSocketType);
+
 	bool validateForm();
 
 private:
